@@ -34,7 +34,7 @@ Version 2.4.2
 
 =cut
 
-our $VERSION = '2.46';
+our $VERSION = '2.47';
 
 =head1 SYNOPSIS
 
@@ -179,13 +179,13 @@ has 'show_processid' => (
     documentation => q{Show the process ID per logging message. This is useful when aggregating logs.}
 );
 
-#has 'verbose' => (
-    #is => 'rw',
-    #isa => enum([qw[0 1]]),
-    #required => 1,
-    #default => 1,
-    #documentation => q{Level of verbosity},
-#);
+has 'metastr' => (
+    is => 'rw',
+    isa => 'Str',
+    default => "",
+    documentation => q{Meta str passed from HPC::Runner::Scheduler},
+    required => 0,
+);
 
 =head1 Internal VARIABLES
 
@@ -586,6 +586,8 @@ sub log_cmd_messages{
 sub log_main_messages{
     my($self, $level, $message)  = @_;
 
+    return unless $message;
+    $level = 'debug' unless $level;
     $self->log->$level($message);
 }
 
